summaryrefslogtreecommitdiffstats
path: root/kimgio/g3r.h
diff options
context:
space:
mode:
Diffstat (limited to 'kimgio/g3r.h')
-rw-r--r--kimgio/g3r.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kimgio/g3r.h b/kimgio/g3r.h
index df90c5dee..f734a9e82 100644
--- a/kimgio/g3r.h
+++ b/kimgio/g3r.h
@@ -1,5 +1,5 @@
/**
* QImageIO Routines to read/write g3 (fax) images.
* (c) 2000, Matthias Hölzer-Klüpfel
*
* This library is distributed under the conditions of the GNU LGPL.
@@ -13,8 +13,8 @@
class QImageIO;
extern "C" {
- void kimgio_g3_read( QImageIO *io );
- void kimgio_g3_write( QImageIO *io );
+ void kimgio_g3_read( TQImageIO *io );
+ void kimgio_g3_write( TQImageIO *io );
}
#endif
@@ -1,5 +1,5 @@
/**
-* QImageIO Routines to read/write g3 (fax) images.
+* TQImageIO Routines to read/write g3 (fax) images.
* (c) 2000, Matthias Hölzer-Klüpfel
*